==> jc-1.4.0.tar.gz: soot/grimp/internal/GNewInvokeExpr.h <==
// public class soot.grimp.internal.GNewInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cd709234ad0500ea soot_grimp_internal_GNewInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStaticInvokeExpr

#include "soot/jimple/internal/AbstractStaticInvokeExpr.h"

#ifndef _JC_soot_grimp_internal_GNewInvokeExpr_H_
#define _JC_soot_grimp_internal_GNewInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs	_jc_soot_grimp_internal_GNewInvokeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs	_jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$refs	_jc_soot_grimp_internal_GNewInvokeExpr$refs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$nonrefs	_jc_soot_grimp_internal_GNewInvokeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$object	_jc_soot_grimp_internal_GNewInvokeExpr$object;

typedef const struct _jc_soot_grimp_internal_GNewInvokeExpr$vmethods	_jc_soot_grimp_internal_GNewInvokeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNewInvokeExpr$vtable	_jc_soot_grimp_internal_GNewInvokeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNewInvokeExpr$vtype	_jc_soot_grimp_internal_GNewInvokeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$_init$e3abae59b1e40b38(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_soot_RefType$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
extern struct _jc_soot_RefType$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$getBaseType$b249be320d6d3409(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
extern jint _jc_soot_grimp_internal_GNewInvokeExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
extern struct _jc_soot_Type$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
extern struct _jc_object *_jc_soot_grimp_internal_GNewInvokeExpr$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$setBaseType$aec1528d245a4bf6(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_soot_RefType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getBaseType$b249be320d6d3409;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$setBaseType$aec1528d245a4bf6;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNewInvokeExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
	struct _jc_soot_RefType$object	*(*getBaseType$b249be320d6d3409)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
	void	(*setBaseType$aec1528d245a4bf6)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_soot_RefType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_grimp_internal_GNewInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GNewInvokeExpr$vmethods	soot_grimp_internal_GNewInvokeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNewInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNewInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs {
	struct _jc_soot_RefType$object	*type;
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNewInvokeExpr$refs {
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs	soot_grimp_internal_GNewInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNewInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs	soot_grimp_internal_GNewInvokeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNewInvokeExpr$object {
	_jc_soot_grimp_internal_GNewInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNewInvokeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNewInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNewInvokeExpr$vtype _jc_soot_grimp_internal_GNewInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNewInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNewInvokeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNewInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GNewInvokeExpr.h <==
// public class soot.grimp.internal.GNewInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cd709234ad0500ea soot_grimp_internal_GNewInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStaticInvokeExpr

#include "soot/jimple/internal/AbstractStaticInvokeExpr.h"

#ifndef _JC_soot_grimp_internal_GNewInvokeExpr_H_
#define _JC_soot_grimp_internal_GNewInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs	_jc_soot_grimp_internal_GNewInvokeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs	_jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$refs	_jc_soot_grimp_internal_GNewInvokeExpr$refs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$nonrefs	_jc_soot_grimp_internal_GNewInvokeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNewInvokeExpr$object	_jc_soot_grimp_internal_GNewInvokeExpr$object;

typedef const struct _jc_soot_grimp_internal_GNewInvokeExpr$vmethods	_jc_soot_grimp_internal_GNewInvokeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNewInvokeExpr$vtable	_jc_soot_grimp_internal_GNewInvokeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNewInvokeExpr$vtype	_jc_soot_grimp_internal_GNewInvokeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$_init$e3abae59b1e40b38(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_soot_RefType$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_RefType$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$getBaseType$b249be320d6d3409(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GNewInvokeExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_grimp_internal_GNewInvokeExpr$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$setBaseType$aec1528d245a4bf6(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GNewInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_internal_GNewInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getBaseType$b249be320d6d3409;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$setBaseType$aec1528d245a4bf6;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GNewInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNewInvokeExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_soot_RefType$object	*(*getBaseType$b249be320d6d3409)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*setBaseType$aec1528d245a4bf6)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_grimp_internal_GNewInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GNewInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GNewInvokeExpr$vmethods	soot_grimp_internal_GNewInvokeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNewInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNewInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs {
	struct _jc_soot_RefType$object	*type;
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNewInvokeExpr$refs {
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_refs	soot_grimp_internal_GNewInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNewInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GNewInvokeExpr$sub_nonrefs	soot_grimp_internal_GNewInvokeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNewInvokeExpr$object {
	_jc_soot_grimp_internal_GNewInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNewInvokeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNewInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNewInvokeExpr$vtype _jc_soot_grimp_internal_GNewInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNewInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNewInvokeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNewInvokeExpr_H_ */
